@@ -167,7 +167,7 @@ static void focus_term (GtkWidget *widget, gpointer data)
     GtkWidget *n = GTK_WIDGET (data);
 
     box = gtk_notebook_get_nth_page (GTK_NOTEBOOK(n), gtk_notebook_get_current_page(GTK_NOTEBOOK(n)));
-    list = gtk_container_children (GTK_CONTAINER(box));
+    list = gtk_container_get_children (GTK_CONTAINER(box));
     gtk_widget_grab_focus (list->data);
 }
 
@@ -216,7 +216,7 @@ static gboolean goto_tab_8  (tilda_window *tw) { return goto_tab_generic (tw, 8)
 static gboolean goto_tab_9  (tilda_window *tw) { return goto_tab_generic (tw, 9);  }
 static gboolean goto_tab_10 (tilda_window *tw) { return goto_tab_generic (tw, 10); }
 
-static void ccopy (tilda_window *tw)
+static gint ccopy (tilda_window *tw)
 {
     DEBUG_FUNCTION ("ccopy");
     DEBUG_ASSERT (tw != NULL);
@@ -229,9 +229,12 @@ static void ccopy (tilda_window *tw)
     current_page = gtk_notebook_get_nth_page (GTK_NOTEBOOK (tw->notebook), pos);
     list = gtk_container_get_children (GTK_CONTAINER(current_page));
     vte_terminal_copy_clipboard (VTE_TERMINAL(list->data));
+
+    /* Stop the event's propagation */
+    return TRUE;
 }
 
-static void cpaste (tilda_window *tw)
+static gint cpaste (tilda_window *tw)
 {
     DEBUG_FUNCTION ("cpaste");
     DEBUG_ASSERT (tw != NULL);
@@ -244,6 +247,9 @@ static void cpaste (tilda_window *tw)
     current_page = gtk_notebook_get_nth_page (GTK_NOTEBOOK (tw->notebook), pos);
     list = gtk_container_get_children (GTK_CONTAINER (current_page));
     vte_terminal_paste_clipboard (VTE_TERMINAL(list->data));
+
+    /* Stop the event's propagation */
+    return TRUE;
 }
 
 static gint tilda_window_setup_keyboard_accelerators (tilda_window *tw)
@@ -389,7 +395,6 @@ tilda_window *tilda_window_init (const gchar *config_file, const gint instance)
     tw->notebook = gtk_notebook_new ();
 
     /* Set up all notebook properties */
-    gtk_notebook_set_homogeneous_tabs (GTK_NOTEBOOK(tw->notebook), TRUE);
     gtk_notebook_set_show_tabs (GTK_NOTEBOOK(tw->notebook), FALSE);
     gtk_notebook_set_show_border (GTK_NOTEBOOK (tw->notebook), config_getbool("notebook_border"));
     tilda_window_set_tab_position (tw, config_getint ("tab_pos"));
